@@ -27,8 +27,11 @@ import abc
 import argparse
 import json
 import logging
+import sys
+from datetime import datetime, timedelta
 from pathlib import Path
 from time import sleep
+from typing import List, Tuple, Optional
 
 import psycopg2 as pg
 
@@ -36,8 +39,7 @@ from tdvisu.dijkstra import bidirectional_dijkstra as find_path
 from tdvisu.utilities import convert_to_adj
 from tdvisu.reader import TwReader
 from tdvisu.visualization import flatten
-from tdvisu.version import __date__, __version__ as version
-from tdvisu.utilities import read_yml_or_cfg, logging_cfg, LOGLEVEL_EPILOG
+from tdvisu.utilities import read_yml_or_cfg, logging_cfg, get_parser
 
 LOGGER = logging.getLogger('construct_dpdb_visu.py')
 
@@ -101,93 +103,94 @@ def db_config(filename: str = 'database.ini',
     return {**DEFAULT_DBCONFIG, **cfg}
 
 
-def query_problem(cur, problem):
+def query_problem(cursor, problem: int) -> str:  # pragma: no cover
     """Query type from public.problem for one problem."""
-    cur.execute("SELECT type FROM "
-                "public.problem WHERE id=%s", (problem,))
-    result = cur.fetchone()
+    cursor.execute("SELECT type FROM "
+                   "public.problem WHERE id=%s", (problem,))
+    result = cursor.fetchone()[0]
     return result
 
 
-def query_num_vars(cur, problem):
+def query_num_vars(cursor, problem: int) -> int:  # pragma: no cover
     """Query num_vertices from public.problem for one problem."""
-    cur.execute(
+    cursor.execute(
         "SELECT num_vertices FROM "
         "public.problem WHERE id=%s", (problem,))
-    result = cur.fetchone()[0]
+    result = cursor.fetchone()[0]
     return result
 
 
-def query_sat_clause(cur, problem):
+def query_sat_clause(cursor, problem: int) -> List[Tuple[Optional[bool]]]:  # pragma: no cover
     """Query sat-clauses for one problem."""
     try:
-        cur.execute("SELECT * FROM public.p%d_sat_clause" % problem)
+        cursor.execute("SELECT * FROM public.p%d_sat_clause" % problem)
     except pg.ProgrammingError:
         LOGGER.error(
             "dpdb.py *SAT needs to be run with '--store-formula'!")
         raise
-    result = cur.fetchall()
+    result = cursor.fetchall()
     return result
 
 
-def query_td_bag_grouped(cur, problem):
+def query_td_bag_grouped(cursor, problem: int) -> List[List[int]]:  # pragma: no cover
     """Query bag-ids for one problem."""
-    cur.execute("SELECT bag FROM public.p%d_td_bag GROUP BY bag" % problem)
-    result = cur.fetchall()
+    cursor.execute("SELECT bag FROM public.p%d_td_bag GROUP BY bag" % problem)
+    result = cursor.fetchall()
     return result
 
 
-def query_td_node_status(cur, problem, bag):
+def query_td_node_status(
+        cursor, problem: int, bag: int) -> Tuple[datetime, timedelta]:  # pragma: no cover
     """Query details about the status of one node.
     Currently start_time and end_time-start_time."""
-    cur.execute(
+    cursor.execute(
         ("SELECT start_time,end_time-start_time "
          "FROM public.p%d_td_node_status" % problem)
         + " WHERE node=%s", (bag,))
-    result = cur.fetchone()
+    result = cursor.fetchone()
     return result
 
 
-def query_td_bag(cur, problem, bag):
+def query_td_bag(cursor, problem: int, bag: int) -> List[Tuple[int]]:  # pragma: no cover
     """Query nodes included in one bag."""
-    cur.execute(
+    cursor.execute(
         ("SELECT node FROM public.p%d_td_bag" % problem)
         + " WHERE bag=%s", (bag,))
-    result = cur.fetchall()
+    result = cursor.fetchall()
     return result
 
 
-def query_td_node_status_ordered(cur, problem):
+def query_td_node_status_ordered(cursor, problem: int) -> List[Tuple[int]]:  # pragma: no cover
     """Query bags ordered by 'start_time'."""
-    cur.execute(
+    cursor.execute(
         "SELECT node FROM public.p%d_td_node_status ORDER BY start_time" %
         problem)
-    result = cur.fetchall()
+    result = cursor.fetchall()
     return result
 
 
-def query_column_name(cur, problem, bag):
+def query_column_name(cursor, problem: int, bag: int) -> List[Tuple[str]]:  # pragma: no cover
     """Query column names for one bag."""
-    cur.execute(
+    cursor.execute(
         "SELECT column_name FROM INFORMATION_SCHEMA.COLUMNS "
         "WHERE TABLE_NAME = 'p%d_td_node_%d'" % (problem, bag))
-    result = cur.fetchall()
+    result = cursor.fetchall()
     return result
 
 
-def query_bag(cur, problem, bag):
+def query_bag(cursor, problem: int, bag: int) -> List[Tuple[Optional[bool]]]:  # pragma: no cover
     """Query solution data for one bag."""
-    cur.execute(
+    cursor.execute(
         "SELECT * FROM public.p%d_td_node_%d" % (problem, bag))
-    result = cur.fetchall()
+    result = cursor.fetchall()
     return result
 
 
-def query_edgearray(cur, problem):
+def query_edgearray(cursor, problem: int) -> List[Tuple[int, int]]:  # pragma: no cover
     """Query edges between bags for one problem."""
-    cur.execute(
+    cursor.execute(
         "SELECT node,parent FROM public.p%d_td_edge" % problem)
-    result = cur.fetchall()
+    result = cursor.fetchall()
     return result
 
 
@@ -212,17 +215,17 @@ class IDpdbVisuConstruct(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def construct(self) -> dict:
         """Return the constructed Json."""
-        raise NotImplementedError
+        raise NotImplementedError   # pragma: no cover
 
     @abc.abstractmethod
     def read_edgearray(self) -> list:
         """Return the edges between the bags."""
-        raise NotImplementedError
+        raise NotImplementedError   # pragma: no cover
 
     @abc.abstractmethod
     def read_labeldict(self) -> list:
         """Construct the corresponding labels for each bag."""
-        raise NotImplementedError
+        raise NotImplementedError   # pragma: no cover
 
     @abc.abstractmethod
     def read_timeline(self, edgearray) -> list:
@@ -230,7 +233,7 @@ class IDpdbVisuConstruct(metaclass=abc.ABCMeta):
             - create the timeline of the solving process
             - construct the path and solution-tables used during solving.
         """
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: no cover
 
 
 class DpdbSharpSatVisu(IDpdbVisuConstruct):
@@ -545,7 +548,7 @@ def create_json(
         with connect() as connection:
             # get type of problem
             with connection.cursor() as cur:
-                (ptype,) = query_problem(cur, problem)
+                ptype = query_problem(cur, problem)
 
             # select the valid constructor for the problem
             constructor: IDpdbVisuConstruct
@@ -570,79 +573,69 @@ def create_json(
     return {}
 
 
-def main(args: argparse.Namespace) -> None:
+def main(args: List[str]) -> None:
     """
-    Main method running construct_dpdb_visu for arguments in 'args'
+    Main method running construct_dpdb_visu for arguments in 'args'.
 
     Parameters
     ----------
-    args : argparse.Namespace
-        The namespace containing all (command-line) parameters.
+    args : List[str]
+        The array containing all (command-line) flags.
 
     Returns
     -------
     None
     """
+    parser = get_parser("Extracts Information from "
+                        "https://github.com/hmarkus/dp_on_dbs runs "
+                        "for further visualization.")
 
-    logging_cfg(filename='logging.yml', loglevel=args.loglevel)
-    LOGGER.info("Called with '%s'", args)
+    parser.add_argument('problemnumber', type=int,
+                        help="selected problem-id in the postgres-database.")
+    parser.add_argument('--twfile',
+                        type=argparse.FileType('r', encoding='UTF-8'),
+                        help="tw-file containing the edges of the graph - "
+                        "obtained from dpdb with option --gr-file GR_FILE.")
+    parser.add_argument('--outfile', default='dbjson%d.json',
+                        help="default:'dbjson%%d.json'")
+    parser.add_argument('--pretty', action='store_true',
+                        help="pretty-print the JSON.")
+    parser.add_argument('--inter-nodes', action='store_true',
+                        help="calculate and animate the shortest path between "
+                        "successive bags in the order of evaluation.")
+    # get cmd-arguments
+    options = parser.parse_args(args)
 
-    problem_ = args.problemnumber
+    logging_cfg(filename='logging.yml', loglevel=options.loglevel)
+    LOGGER.info("Called with '%s'", options)
+    problem_ = options.problemnumber
     # get twfile if supplied
     try:
-        tw_file_ = args.twfile
+        tw_file_ = options.twfile
     except AttributeError:
         tw_file_ = None
+
+    # create JSON
     result_json = create_json(problem=problem_, tw_file=tw_file_)
-    # build json filename, can be supplied with problem-number
-    try:
-        outfile = args.outfile % problem_
+    try:    # build json filename, can be supplied with problem-number
+        outfile = options.outfile % problem_
     except TypeError:
-        outfile = args.outfile
+        outfile = options.outfile
     LOGGER.info("Output file-name: %s", outfile)
     with open(outfile, 'w') as file:
         json.dump(
             result_json,
             file,
             sort_keys=True,
-            indent=2 if args.pretty else None,
+            indent=2 if options.pretty else None,
             ensure_ascii=False)
         LOGGER.debug("Wrote to %s", file)
 
 
-if __name__ == "__main__":
-    # Parse args, call main
+def init():
+    """Initialization that is executed at the time of the module import."""
+    if __name__ == "__main__":
+        sys.exit(main(sys.argv[1:]))  # call main function
 
-    PARSER = argparse.ArgumentParser(
-        description="""
-        Copyright (C) 2020 Martin Röbke
-        This program comes with ABSOLUTELY NO WARRANTY
-        This is free software, and you are welcome to redistribute it
-        under certain conditions; see COPYING for more information.
 
-        Extracts Information from https://github.com/hmarkus/dp_on_dbs runs
-        for further visualization.""",
-        epilog=LOGLEVEL_EPILOG,
-        formatter_class=argparse.RawDescriptionHelpFormatter
-    )
-
-    PARSER.add_argument('problemnumber', type=int,
-                        help="selected problem-id in the postgres-database.")
-    PARSER.add_argument('--twfile',
-                        type=argparse.FileType('r', encoding='UTF-8'),
-                        help="tw-file containing the edges of the graph - "
-                        "obtained from dpdb with option --gr-file GR_FILE.")
-    PARSER.add_argument('--loglevel', help="set the minimal loglevel for root")
-    PARSER.add_argument('--outfile', default='dbjson%d.json',
-                        help="default:'dbjson%%d.json'")
-    PARSER.add_argument('--pretty', action='store_true',
-                        help="pretty-print the JSON.")
-    PARSER.add_argument('--inter-nodes', action='store_true',
-                        help="calculate and animate the shortest path between "
-                        "successive bags in the order of evaluation.")
-    PARSER.add_argument('--version', action='version',
-                        version='%(prog)s ' + version + ', ' + __date__)
-
-    # get cmd-arguments
-    _args = PARSER.parse_args()
-    main(_args)
+init()
