@@ -126,7 +126,7 @@ class VisualizationData:
                          **self.emphasis}
 
 
-if __name__ == "__main__":
+if __name__ == "__main__":  # pragma: no cover
     # Just Testing:
     incid = [IncidenceGraphData([])]
     gen = [GeneralGraphData([])]
